@@ -6,29 +6,31 @@ Usage example: read_gsheet("https://sheet.google.com/45qwd3533")
 """
 
 
-def read_gsheet(url, credentials=None, sheet=None):
-    import gspread
+def read_gsheet(url, credentials = None, sheet = None):
 
     if credentials != True:
+
         gc = gspread.service_account(credentials)
 
-    if sheet != None:
+        if sheet != None:
 
-        wks = gc.open_by_url(url).worksheet(sheet)
+            wks = gc.open_by_url(url).worksheet(sheet)
 
-    else:
+        else:
 
-        wks = gc.open_by_url(url).get_worksheet(0)
+            wks = gc.open_by_url(url).get_worksheet(0)
 
-    data = wks.get_values(value_render_option='UNFORMATTED_VALUE', date_time_render_option="FORMATTED_STRING")
 
-    headers = data.pop(0)
+        data = wks.get_values(value_render_option='UNFORMATTED_VALUE', date_time_render_option = "FORMATTED_STRING")
 
-    df = pd.DataFrame(data, columns=headers)
+        headers = data.pop(0)
 
-    # else:
+        df = pd.DataFrame(data, columns = headers)
 
-    # df = ##chiamata API
+
+    #else: 
+
+        #df = ##chiamata API
 
     return df
 
@@ -142,4 +144,33 @@ def __read_gsheet(settings: dict):
 def __read_hubspot(settings: dict):
     df = read_hubspot_contacts(settings["fields"]["token"])
 
-    return df
\ No newline at end of file
+    return df
+
+
+
+
+##################################
+########## FACEBOOK ADS ##########
+##################################
+
+
+def read_fb_ads(my_app_id, my_app_secret, my_access_token,
+                date_preset = "today",
+               account_name = {'Numbers' : 'act_113103090066338',
+                'Linkers' : 'act_203938767415072',
+                'WinWay' : 'act_2591302164494270',
+                'Miss Tariffa Agency' : 'act_280378753012689',
+                'Humable' : 'act_284748836042514',
+                'Miss Tariffa' : 'act_503932150489858',
+                'We are Fiber' : 'act_638714426864395'
+               }):
+    
+    from askdata.integrations import facebook_api
+    
+    fb_ads = facebook_api.get_fb_ads(my_app_id, my_app_secret, my_access_token, date_preset, account_name)
+
+    return fb_ads
+
+
+
+
